{ config, lib, pkgs, user, ... }:
let
  font.name = "DejaVu Sans Mono";
  font.size = 12.0;
in
{
  imports = [
    ./i3status-rust.nix
  ];

  home.packages = with pkgs; [
    xdg-utils
  ];

  programs.fuzzel = {
    enable = true;
    settings = {
      main = {
        terminal = "${pkgs.kitty}/bin/kitty";
        layer = "overlay";
        font = "DejaVu Sans Mono:size=12";
      };
      colors = {
        background = "002b36ff";
        border = "ffffffaa";
      };
    };
  };
    };
  };

  wayland.windowManager.sway = {
    enable = true;

    config = rec {
      modifier = "Mod4";
      terminal = "${pkgs.kitty}/bin/kitty";

      input = {
        "type:keyboard" = {
          xkb_layout = "de";
        };
        "type:touchpad" = {
          natural_scroll = "enabled";
          tap = "enabled";
          accel_profile = "flat";
          dwt = "enabled";
        };
      };

      seat = {
        "*" = {
          hide_cursor = "1000";
        };
      };

      fonts = {
        names = [ font.name ];
        size = font.size;
      };

      bars = [{
        mode = "hide";
        position = "top";
        statusCommand = "${pkgs.i3status-rust}/bin/i3status-rs ~/.config/i3status-rust/config-default.toml";

        fonts = {
          names = [ font.name ];
          size = font.size;
        };
      }];

      menu = "${pkgs.fuzzel}/bin/fuzzel";
    };

    extraConfig = ''
    '';
  };

}
